Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Debug debug.Config
Server server.Config
Crash crash.Config
Identity identity.Config
}
Config is the global configuration for storj crash collect service.
type Peer ¶
type Peer struct {
Log *zap.Logger
Config Config
Identity *identity.FullIdentity
Server *server.Server
Crash struct {
Service *crash.Service
Endpoint *crash.Endpoint
}
}
Peer is the representation of a storj crash collect service.
architecture: Peer
Click to show internal directories.
Click to hide internal directories.